# Autograder JS

Esta biblioteca permite avaliar código JavaScript utilizando a API do OpenAI para fornecer feedback sem entregar a resposta completa.

## Instalação

1. Clone o repositório:
   ```bash
   git clone https://github.com/luccahiratsuca/autograder.git
   cd autograder
    ```

Para subir o pacote para o PyPi, siga os passos abaixo:
   ```bash
   python setup.py sdist bdist_wheel
   ```

    ```bash
    twine upload dist/*
    ```
